@@ -33,7 +33,7 @@ class Application extends Container implements ApplicationContract, CachesConfig
      *
      * @var string
      */
-    const VERSION = '7.12.0';
+    const VERSION = '7.30.2';
 
     /**
      * The base path for the Laravel installation.
@@ -152,7 +152,7 @@ class Application extends Container implements ApplicationContract, CachesConfig
      *
      * @var array
      */
-    protected $absoluteCachePathPrefixes = [DIRECTORY_SEPARATOR];
+    protected $absoluteCachePathPrefixes = ['/', '\\'];
 
     /**
      * Create a new Illuminate application instance.
@@ -1102,6 +1102,17 @@ class Application extends Container implements ApplicationContract, CachesConfig
         return $this->loadedProviders;
     }
 
+    /**
+     * Determine if the given service provider is loaded.
+     *
+     * @param  string  $provider
+     * @return bool
+     */
+    public function providerIsLoaded(string $provider)
+    {
+        return isset($this->loadedProviders[$provider]);
+    }
+
     /**
      * Get the application's deferred services.
      *
@@ -1166,6 +1177,16 @@ class Application extends Container implements ApplicationContract, CachesConfig
         return $this['config']->get('app.locale');
     }
 
+    /**
+     * Get the current application fallback locale.
+     *
+     * @return string
+     */
+    public function getFallbackLocale()
+    {
+        return $this['config']->get('app.fallback_locale');
+    }
+
     /**
      * Set the current application locale.
      *
@@ -1181,6 +1202,19 @@ class Application extends Container implements ApplicationContract, CachesConfig
         $this['events']->dispatch(new LocaleUpdated($locale));
     }
 
+    /**
+     * Set the current application fallback locale.
+     *
+     * @param  string  $fallbackLocale
+     * @return void
+     */
+    public function setFallbackLocale($fallbackLocale)
+    {
+        $this['config']->set('app.fallback_locale', $fallbackLocale);
+
+        $this['translator']->setFallback($fallbackLocale);
+    }
+
     /**
      * Determine if application locale is the given locale.
      *
